@@ -3,7 +3,7 @@ from typing import Any
 from django.contrib.auth.models import User
 from rest_framework import serializers
 
-from blog.models import ( Comment, EntryEnvelope, Tag, View, Interaction )
+from blog.models import ( Comment, EntryEnvelope, Tag, View, Interaction, VisitorProfile )
 
 
 class EntrySerializer(serializers.BaseSerializer):
@@ -136,3 +136,9 @@ class InteractionSerializer(serializers.ModelSerializer):
     class Meta:
         model = Interaction
         fields = '__all__'
+
+
+class VisitorProfileSerializer(serializers.ModelSerializer):
+    class Meta:
+        model = VisitorProfile
+        fields = ('id', 'device', 'family', 'language', 'name', 'os_version', 'telemetry', 'version')
